# Silence: An educational framework for deploying RESTful APIs and Web applications. [![Build Status](https://travis-ci.org/agu-borrego/Silence.svg?branch=master)](https://travis-ci.org/agu-borrego/Silence)

Work in progress.

## Disclaimer
Silence has been designed and built with educational-only purposes in mind. It makes no specific efforts to ensure neither efficiency nor security. It should **NOT** be used in a production environment of any kind.

## License
MIT License
